.htaccess
.user.ini
AUTHORS
CHANGELOG.md
COPYING
README.md
apps
config
console.php
core
cron.php
db_structure.xml
index.html
index.php
lib
occ
ocm-provider
ocs
ocs-provider
public.php
remote.php
resources
robots.txt
settings
status.php
updater
version.php
apps-external